@@ -171,7 +171,8 @@ class Module(core.input.Object):
     """
 
     def add_widget(self, full_text="", name=None):
-        widget = core.widget.Widget(full_text=full_text, name=name)
+        widget_id = "{}::{}".format(self.name, len(self.widgets()))
+        widget = core.widget.Widget(full_text=full_text, name=name, widget_id=widget_id)
         self.widgets().append(widget)
         widget.module = self
         return widget
@@ -184,12 +185,14 @@ class Module(core.input.Object):
     :rtype: bumblebee_status.widget.Widget
     """
 
-    def widget(self, name=None):
-        if not name:
+    def widget(self, name=None, widget_id=None):
+        if not name and not widget_id:
             return self.widgets()[0]
 
         for w in self.widgets():
-            if w.name == name:
+            if name and w.name == name:
+                return w
+            if w.id == widget_id:
                 return w
         return None
 
